## adapted from: http://blogs.msdn.com/b/powershell/archive/2006/10/16/windows-powershell-font-customization.aspx
## 4/18/2019 - Elwix/Style

$key = "HKLM:\SOFTWARE\Microsoft\Windows NT\CurrentVersion\Console\TrueTypeFont"

## determine if C64 Pro Mono is installed on the system
if(!(test-path (join-path $env:windir "Fonts\C64_Pro_Mono-STYLE.ttf")) -And
   !(test-path (join-path $env:windir "Fonts\C64 Pro Mono.ttf"))) {
	write-host "`nC64 Pro Mono is not installed on the system.`n"
	break
}

## report currently enabled cmd/powershell fonts
write-host "`nCurrently enabled: "
(Get-ItemProperty $key).psobject.properties | where {$_.Name -match "^0+$"} | Sort-Object Value | foreach { write-host " - " $_.Value }

## determine if C64 Pro Mono is already enabled as a cmd/powershell font
$installed = get-itemproperty $key |  get-member | where-object { $_.Name -match "^0+$" } |
	where-object { $_.Definition -match "C64 Pro Mono" }
if($installed -ne $null) {
	write-host "`nThe C64 Pro Mono font is already installed as a cmd/powershell font.`n"
	break
}

## determine what the largest string of zeros is
$zeros = (get-itemproperty $key | get-member |
	where-object { $_.Name -match "^0+$" } | measure-object).Count

## if we don't have admin credentials we can't modify the registry...
$id = [Security.Principal.WindowsIdentity]::GetCurrent()
If (-not ([Security.Principal.WindowsPrincipal] $id).IsInRole([Security.Principal.WindowsBuiltInRole]::Administrator)) {
	Write-host
	Write-Warning "Without admin privileges, this script cannot modify the registry. No change has been made - rerun as an administrator.`n`n"
	break
}

## install the font
$output = new-itemproperty $key -Name ("0" * ($zeros + 1)) -Type string -Value "C64 Pro Mono"
write-host "`nSUCCESS: C64 Pro Mono was configured as a cmd/powershell font.`n"
